==============
pystata-kernel
==============

A simple Jupyter kernel for Stata based on *pystata* (https://www.stata.com/python/pystata/). Requires Stata 17 or above.
Consider *stata_kernel* (https://github.com/kylebarron/stata_kernel) instead if you have an older version of Stata. 

Installation
------------

See https://github.com/ticoneva/pystata-kernel for instructions.
